@@ -16,7 +16,7 @@ def init_admin():
 
     try:
         User.objects.get(username='admin', is_superuser=True)
-        print('Admin user already exists, you can use them to login:')
+        print('Admin user already exists, you can use admin to login:')
     except:
         username = 'admin'
         email = f'{username}@bomiot.com'
