@@ -258,4 +258,12 @@ def init_bomiot():
               'and change the password for safety' % \
               ('Created' if created else 'Reset', username, email, password))
     print('系统启动成功')
+    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    s.connect(('8.8.8.8', 80))
+    ip = s.getsockname()[0]
+    print('本机IP地址为:', ip)
+    s.close()
+    baseurl = "http://" + ip + ":8008"
+    print('浏览器正在打开:', baseurl)
+    webbrowser.open(baseurl)
     
\ No newline at end of file
